@@ -6,13 +6,9 @@
 // option. This file may not be copied, modified, or distributed
 // except according to those terms.
 
-extern crate docopt;
-#[macro_use]
-extern crate log;
-extern crate rustc_serialize;
-extern crate stderrlog;
-
 use docopt::Docopt;
+use log::*;
+use serde::Deserialize;
 use std::env;
 
 const USAGE: &'static str = "
@@ -20,7 +16,7 @@ Usage:
   stderrtest [-q] [-v...]
 ";
 
-#[derive(RustcDecodable)]
+#[derive(Deserialize)]
 struct Args {
     flag_v: usize,
     flag_q: bool,
@@ -28,7 +24,7 @@ struct Args {
 
 fn main() {
     let args: Args = Docopt::new(USAGE)
-        .and_then(|d| d.argv(env::args().into_iter()).decode())
+        .and_then(|d| d.argv(env::args().into_iter()).deserialize())
         .unwrap_or_else(|e| e.exit());
 
     stderrlog::new()
